==> ikaaro-0.50.5.tar.gz: ikaaro-0.50.5/ui/tiny_mce/themes/advanced/langs/de_dlg.js <==
tinyMCE.addI18n('de.advanced_dlg',{
about_title:"\u00DCber TinyMCE",
about_general:"\u00DCber\u2026",
about_help:"Hilfe",
about_license:"Lizenzbedingungen",
about_plugins:"Plugins",
about_plugin:"Plugin",
about_author:"Urheber",
about_version:"Version",
about_loaded:"Geladene Plugins",
anchor_title:"Anker einf\u00FCgen/ver\u00E4ndern",
anchor_name:"Name des Ankers",
code_title:"HTML-Quellcode bearbeiten",
code_wordwrap:"Automatischer Zeilenumbruch",
colorpicker_title:"Farbe",
colorpicker_picker_tab:"Farbwahl",
colorpicker_picker_title:"Farbwahl",
colorpicker_palette_tab:"Palette",
colorpicker_palette_title:"Farbpalette",
colorpicker_named_tab:"Benannte Farben",
colorpicker_named_title:"Benannte Farben",
colorpicker_color:"Farbe:",
colorpicker_name:"Name:",
charmap_title:"Sonderzeichen",
image_title:"Bild einf\u00FCgen/bearbeiten",
image_src:"Adresse",
image_alt:"Alternativtext",
image_list:"Bilderliste",
image_border:"Rahmen",
image_dimensions:"Ausma\u00DFe",
image_vspace:"Vertikaler Abstand",
image_hspace:"Horizontaler Abstand",
image_align:"Ausrichtung",
image_align_baseline:"Zeile",
image_align_top:"Oben",
image_align_middle:"Mittig",
image_align_bottom:"Unten",
image_align_texttop:"Oben im Text",
image_align_textbottom:"Unten im Text",
image_align_left:"Links",
image_align_right:"Rechts",
link_title:"Link einf\u00FCgen/bearbeiten",
link_url:"Adresse",
link_target:"Fenster",
link_target_same:"Im selben Fenster \u00F6ffnen",
link_target_blank:"Neues Fenster \u00F6ffnen",
link_titlefield:"Titel",
link_is_email:"Bei der Adresse scheint es sich um eine E-Mail-Adresse zu handeln. Wollen Sie das dazu ben\u00F6tigte mailto: voranstellen?",
link_is_external:"Bei der Adresse scheint es sich um einen externen Link zu handeln. M\u00F6chten Sie, dass zur korrekten Verlinkung ein http:// vorangestellt wird?",
link_list:"Linkliste"
});

==> ikaaro-0.61.4.tar.gz: ikaaro-0.61.4/ui/tiny_mce/themes/advanced/langs/de_dlg.js <==
tinyMCE.addI18n('de.advanced_dlg',{
about_title:"\u00DCber TinyMCE",
about_general:"\u00DCber",
about_help:"Hilfe",
about_license:"Lizenzbedingungen",
about_plugins:"Plugins",
about_plugin:"Plugin",
about_author:"Urheber",
about_version:"Version",
about_loaded:"Geladene Plugins",
anchor_title:"Anker einf\u00FCgen/ver\u00E4ndern",
anchor_name:"Name des Ankers",
code_title:"HTML-Quellcode bearbeiten",
code_wordwrap:"Automatischer Zeilenumbruch",
colorpicker_title:"Farbe",
colorpicker_picker_tab:"Farbwahl",
colorpicker_picker_title:"Farbwahl",
colorpicker_palette_tab:"Palette",
colorpicker_palette_title:"Farbpalette",
colorpicker_named_tab:"Benannte Farben",
colorpicker_named_title:"Benannte Farben",
colorpicker_color:"Farbe:",
colorpicker_name:"Name:",
charmap_title:"Sonderzeichen",
image_title:"Bild einf\u00FCgen/bearbeiten",
image_src:"Adresse",
image_alt:"Alternativtext",
image_list:"Bilderliste",
image_border:"Rahmen",
image_dimensions:"Abmessungen",
image_vspace:"Vertikaler Abstand",
image_hspace:"Horizontaler Abstand",
image_align:"Ausrichtung",
image_align_baseline:"Zeile",
image_align_top:"Oben",
image_align_middle:"Mittig",
image_align_bottom:"Unten",
image_align_texttop:"Oben im Text",
image_align_textbottom:"Unten im Text",
image_align_left:"Links",
image_align_right:"Rechts",
link_title:"Link einf\u00FCgen/bearbeiten",
link_url:"Adresse",
link_target:"Fenster",
link_target_same:"Im selben Fenster \u00F6ffnen",
link_target_blank:"Neues Fenster \u00F6ffnen",
link_titlefield:"Titel",
link_is_email:"Diese Adresse scheint eine E-Mail-Adresse zu sein. M\u00F6chten Sie das dazu ben\u00F6tigte \"mailto:\" voranstellen?",
link_is_external:"Diese Adresse scheint ein externer Link zu sein. M\u00F6chten Sie das dazu ben\u00F6tigte \"http://\" voranstellen?",
link_list:"Linkliste"
});
